@@ -1,5 +1,5 @@
 package Proc::Pidfile;
-$Proc::Pidfile::VERSION = '1.06_01';
+$Proc::Pidfile::VERSION = '1.06_03';
 use 5.006;
 use strict;
 use warnings;
@@ -172,7 +172,7 @@ the curent process
 
     my $pp = Proc::Pidfile->new();
     # creates pidfile in default location - /var/run or File::Spec->tmpdir ...
-    my $pidfile = $pp=>pidfile();
+    my $pidfile = $pp->pidfile();
     # tells you where this pidfile is ...
 
     my $pp = Proc::Pidfile->new( silent => 1 );
